@@ -4,10 +4,9 @@ from typing import Callable, Dict, List, Any, Tuple
 from cadCAD.utils import flatten
 from cadCAD.utils.execution import print_exec_info
 from cadCAD.configuration import Configuration, Processor
-from cadCAD.configuration.utils import TensorFieldReport, configs_as_objs
+from cadCAD.configuration.utils import TensorFieldReport, configs_as_objs, configs_as_dicts
 from cadCAD.engine.simulation import Executor as SimExecutor
 from cadCAD.engine.execution import single_proc_exec, parallelize_simulations, local_simulations
-from cadCAD.configuration.utils import configs_as_dicts
 
 VarDictType = Dict[str, List[Any]]
 StatesListsType = List[Dict[str, Any]]
@@ -36,19 +35,19 @@ class ExecutionContext:
             self.method = parallelize_simulations
         elif context == 'dist_proc':
             def distroduce_proc(
-                    simulation_execs, var_dict_list, states_lists, configs_structs, env_processes_list, Ts, RunIDs,
+                    simulation_execs, var_dict_list, states_lists, configs_structs, env_processes_list, Ts, SimIDs, RunIDs,
                     ExpIDs,
                     SubsetIDs,
                     SubsetWindows,
-                    exec_method,
+                    configured_n, # exec_method,
                     sc, additional_objs=additional_objs
             ):
                 return method(
-                    simulation_execs, var_dict_list, states_lists, configs_structs, env_processes_list, Ts, RunIDs,
+                    simulation_execs, var_dict_list, states_lists, configs_structs, env_processes_list, Ts, SimIDs, RunIDs,
                     ExpIDs,
                     SubsetIDs,
                     SubsetWindows,
-                    exec_method,
+                    configured_n, # exec_method,
                     sc, additional_objs
                 )
 
@@ -57,15 +56,19 @@ class ExecutionContext:
 
 class Executor:
     def __init__(self,
-             exec_context: ExecutionContext, configs: List[Configuration], spark_context=None
+             exec_context: ExecutionContext, configs: List[Configuration], sc=None, empty_return=False
     ) -> None:
-        self.sc = spark_context
+        self.sc = sc
         self.SimExecutor = SimExecutor
         self.exec_method = exec_context.method
         self.exec_context = exec_context.name
         self.configs = configs
+        self.empty_return = empty_return
 
     def execute(self) -> Tuple[Any, Any, Dict[str, Any]]:
+        if self.empty_return is True:
+            return [], [], []
+
         config_proc = Processor()
         create_tensor_field = TensorFieldReport(config_proc).create_tensor_field
 
@@ -77,6 +80,7 @@ class Executor:
         partial_state_updates, sim_executors = [], []
         config_idx = 0
 
+        # Execution Info
         print_exec_info(self.exec_context, configs_as_objs(self.configs))
 
         t1 = time()
@@ -94,16 +98,16 @@ class Executor:
             ExpIDs.append(x.experiment_id)
             ExpWindows.append(x.exp_window)
             SimIDs.append(x.simulation_id)
-            RunIDs.append(x.run_id)
             SubsetIDs.append(x.subset_id)
+            RunIDs.append(x.run_id)
             SubsetWindows.append(x.subset_window)
 
             var_dict_list.append(x.sim_config['M'])
             states_lists.append([x.initial_state])
             eps.append(list(x.exogenous_states.values()))
-            configs_structs.append(config_proc.generate_config(x.initial_state, x.partial_state_updates, eps[config_idx]))
+            configs_structs.append(config_proc.generate_config(x.initial_state, x.partial_state_update_blocks, eps[config_idx]))
             env_processes_list.append(x.env_processes)
-            partial_state_updates.append(x.partial_state_updates)
+            partial_state_updates.append(x.partial_state_update_blocks)
             sim_executors.append(SimExecutor(x.policy_ops).simulation)
 
             config_idx += 1
@@ -121,7 +125,7 @@ class Executor:
             flat_simulations = flatten(flat_timesteps)
             if config_amt == 1:
                 return simulations, tensor_fields, sessions
-            elif (config_amt > 1): # and (config_amt < remote_threshold):
+            elif config_amt > 1:
                 return flat_simulations, tensor_fields, sessions
 
         remote_threshold = 100
@@ -131,16 +135,13 @@ class Executor:
             try:
                 if config_amt == 1:
                     return ExecutionMode.single_mode, single_proc_exec
-                elif (config_amt > 1): # and (config_amt < remote_threshold):
+                elif (config_amt > 1):
                     return ExecutionMode.multi_mode, parallelize_simulations
             except AttributeError:
                 if config_amt < 1:
-                    raise ValueError('N must be > 1!')
-                # elif config_amt > remote_threshold:
-                #     print('Remote Threshold is N=100. Use ExecutionMode.dist_proc if N >= 100')
+                    raise ValueError('N must be >= 1!')
 
         final_result = None
-        # original_context = self.exec_context
         original_N = len(configs_as_dicts(self.configs))
         if self.exec_context != ExecutionMode.distributed:
             # Consider Legacy Support
@@ -152,6 +153,7 @@ class Executor:
                 sim_executors, var_dict_list, states_lists, configs_structs, env_processes_list, Ts, SimIDs, RunIDs,
                 ExpIDs, SubsetIDs, SubsetWindows, original_N
             )
+
             final_result = get_final_results(simulations_results, partial_state_updates, eps, sessions, remote_threshold)
         elif self.exec_context == ExecutionMode.distributed:
             print("Execution Method: " + self.exec_method.__name__)
