@@ -2,13 +2,13 @@ import pandas as pd
 from tabulate import tabulate
 from cadCAD.engine import ExecutionMode, ExecutionContext, Executor
 from documentation.examples import sys_model_A
-from cadCAD import configs
+from documentation.examples.sys_model_A import exp
 
 exec_mode = ExecutionMode()
 
 # Single Process Execution using a Single System Model Configuration:
 local_proc_ctx = ExecutionContext(context=exec_mode.local_mode)
-sys_model_A_simulation = Executor(exec_context=local_proc_ctx, configs=configs)
+sys_model_A_simulation = Executor(exec_context=local_proc_ctx, configs=exp.configs)
 
 sys_model_A_raw_result, sys_model_A_tensor_field, sessions = sys_model_A_simulation.execute()
 sys_model_A_result = pd.DataFrame(sys_model_A_raw_result)
@@ -17,4 +17,4 @@ print("Tensor Field: sys_model_A")
 print(tabulate(sys_model_A_tensor_field, headers='keys', tablefmt='psql'))
 print("Result: System Events DataFrame")
 print(tabulate(sys_model_A_result, headers='keys', tablefmt='psql'))
-print()
\ No newline at end of file
+print()
